@@ -111,11 +111,11 @@ def start_strategy(api_setting):
 if __name__ == '__main__':
     print("启动量化系统: 等待策略运行")
     api_setting = {
-        "key": "dd45995f-8b74-4185-974a-fd120c39db37",
-        "secret": "CE06411A60DD74A731CA91A60DB562DB",
+        "key": "",
+        "secret": "",
         "proxy_host": "",
         "proxy_port": 0,
-        "Passphrase": "Test1.123",
+        "Passphrase": "",
 
         "call_order_switch": False,  # 订单数据回调 开关
         "call_tick_switch": False,  # tick数据回调 开关
