@@ -138,7 +138,9 @@ class BinanceFutureInverseGateway(BaseGateway):
             price: float = 0,  # 价格
             maker: bool = False,  # 限价单
             stop_loss: bool = False,  # 止损
+            stop_loss_price: float = 0,  # 止损价
             stop_profit: bool = False,  # 止盈
+            stop_profit_price: float = 0,  # 止盈价
             position_side: PositionSide = PositionSide.ONEWAY,
             ):
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -148,7 +150,7 @@ class BinanceFutureInverseGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.LONG,
             offset=Offset.OPEN,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
@@ -164,7 +166,9 @@ class BinanceFutureInverseGateway(BaseGateway):
              price: float = 0,  # 价格
              maker: bool = False,  # 限价单
              stop_loss: bool = False,  # 止损
+             stop_loss_price: float = 0,  # 止损价
              stop_profit: bool = False,  # 止盈
+             stop_profit_price: float = 0,  # 止盈价
              position_side: PositionSide = PositionSide.ONEWAY,
              ):
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -174,7 +178,7 @@ class BinanceFutureInverseGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.SHORT,
             offset=Offset.CLOSE,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
@@ -190,7 +194,9 @@ class BinanceFutureInverseGateway(BaseGateway):
               price: float = 0,  # 价格
               maker: bool = False,  # 限价单
               stop_loss: bool = False,  # 止损
+              stop_loss_price: float = 0,  # 止损价
               stop_profit: bool = False,  # 止盈
+              stop_profit_price: float = 0,  # 止盈价
               position_side: PositionSide = PositionSide.ONEWAY,
               ):
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -200,7 +206,7 @@ class BinanceFutureInverseGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.SHORT,
             offset=Offset.OPEN,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
@@ -216,7 +222,9 @@ class BinanceFutureInverseGateway(BaseGateway):
               price: float = 0,  # 价格
               maker: bool = False,  # 限价单
               stop_loss: bool = False,  # 止损
+              stop_loss_price: float = 0,  # 止损价
               stop_profit: bool = False,  # 止盈
+              stop_profit_price: float = 0,  # 止盈价
               position_side: PositionSide = PositionSide.ONEWAY,
               ):
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -226,7 +234,7 @@ class BinanceFutureInverseGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.LONG,
             offset=Offset.CLOSE,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
@@ -456,10 +464,10 @@ class BinanceInverseRestApi(RestClient):
             params["type"] = "MARKET"  # 市价单
         elif req.type == OrderType.STOP_MARKET:
             params["type"] = "STOP_MARKET"  # 止损单
-            params["stopPrice"] = req.price
+            params["stopPrice"] = req.stop_loss_price
         elif req.type == OrderType.TAKE_PROFIT_MARKET:
             params["type"] = "TAKE_PROFIT_MARKET"  # 止赢单
-            params["stopPrice"] = req.price
+            params["stopPrice"] = req.stop_profit_price
         else:
             order_type, time_condition = ORDERTYPE_VT2BINANCES[req.type]
             params["type"] = order_type
