@@ -135,7 +135,9 @@ class BinanceFutureUsdtGateway(BaseGateway):
             price: float = 0,  # 价格
             maker: bool = False,  # 限价单
             stop_loss: bool = False,  # 止损
+            stop_loss_price: float = 0,  # 止损价
             stop_profit: bool = False,  # 止盈
+            stop_profit_price: float = 0,  # 止盈价
             position_side: PositionSide = PositionSide.ONEWAY,
             ):
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -145,7 +147,7 @@ class BinanceFutureUsdtGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.LONG,
             offset=Offset.OPEN,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
@@ -161,7 +163,9 @@ class BinanceFutureUsdtGateway(BaseGateway):
              price: float = 0,  # 价格
              maker: bool = False,  # 限价单
              stop_loss: bool = False,  # 止损
+             stop_loss_price: float = 0,  # 止损价
              stop_profit: bool = False,  # 止盈
+             stop_profit_price: float = 0,  # 止盈价
              position_side: PositionSide = PositionSide.ONEWAY,
              ):
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -171,7 +175,7 @@ class BinanceFutureUsdtGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.SHORT,
             offset=Offset.CLOSE,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
@@ -187,7 +191,9 @@ class BinanceFutureUsdtGateway(BaseGateway):
               price: float = 0,  # 价格
               maker: bool = False,  # 限价单
               stop_loss: bool = False,  # 止损
+              stop_loss_price: float = 0,  # 止损价
               stop_profit: bool = False,  # 止盈
+              stop_profit_price: float = 0,  # 止盈价
               position_side: PositionSide = PositionSide.ONEWAY,
               ):
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -197,7 +203,7 @@ class BinanceFutureUsdtGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.SHORT,
             offset=Offset.OPEN,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
@@ -213,7 +219,9 @@ class BinanceFutureUsdtGateway(BaseGateway):
               price: float = 0,  # 价格
               maker: bool = False,  # 限价单
               stop_loss: bool = False,  # 止损
+              stop_loss_price: float = 0,  # 止损价
               stop_profit: bool = False,  # 止盈
+              stop_profit_price: float = 0,  # 止盈价
               position_side: PositionSide = PositionSide.ONEWAY,
               ):
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -223,7 +231,7 @@ class BinanceFutureUsdtGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.LONG,
             offset=Offset.CLOSE,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
@@ -456,10 +464,10 @@ class BinanceUsdtRestApi(RestClient):
             params["type"] = "MARKET"  # 市价单
         elif req.type == OrderType.STOP_MARKET:
             params["type"] = "STOP_MARKET"  # 止损单
-            params["stopPrice"] = req.price
+            params["stopPrice"] = req.stop_loss_price
         elif req.type == OrderType.TAKE_PROFIT_MARKET:
             params["type"] = "TAKE_PROFIT_MARKET"  # 止赢单
-            params["stopPrice"] = req.price
+            params["stopPrice"] = req.stop_profit_price
         else:
             order_type, time_condition = ORDERTYPE_VT2BINANCES[req.type]
             params["type"] = order_type
