@@ -44,7 +44,8 @@ STATUS_OKEX2VT: Dict[str, Status] = {
 ORDERTYPE_OKEX2VT: Dict[str, OrderType] = {
     "limit": OrderType.LIMIT,
     "market": OrderType.MARKET,
-    "conditional": OrderType.MARKET
+    "conditional": OrderType.MARKET,
+    "oco": OrderType.STOP_LOSS_PROFIT
 }
 ORDERTYPE_VT2OKEX: Dict[OrderType, str] = {v: k for k, v in ORDERTYPE_OKEX2VT.items()}
 
@@ -182,7 +183,9 @@ class OkexFutureUsdtGateway(BaseGateway):
             price: float = 0,  # 价格
             maker: bool = False,  # 限价单
             stop_loss: bool = False,  # 止损
+            stop_loss_price: float = 0,  # 止损价
             stop_profit: bool = False,  # 止盈
+            stop_profit_price: float = 0,  # 止盈价
             position_side: PositionSide = PositionSide.ONEWAY,
             ):
 
@@ -193,11 +196,13 @@ class OkexFutureUsdtGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.LONG,
             offset=Offset.OPEN,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
-            exchange=self.exchange
+            exchange=self.exchange,
+            stop_loss_price=stop_loss_price,
+            stop_profit_price=stop_profit_price
         )
         return self.send_order(original_req, orderid)
 
@@ -209,7 +214,9 @@ class OkexFutureUsdtGateway(BaseGateway):
              price: float = 0,  # 价格
              maker: bool = False,  # 限价单
              stop_loss: bool = False,  # 止损
+             stop_loss_price: float = 0,  # 止损价
              stop_profit: bool = False,  # 止盈
+             stop_profit_price: float = 0,  # 止盈价
              position_side: PositionSide = PositionSide.ONEWAY,
              ):
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -219,11 +226,13 @@ class OkexFutureUsdtGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.SHORT,
             offset=Offset.CLOSE,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
-            exchange=self.exchange
+            exchange=self.exchange,
+            stop_loss_price=stop_loss_price,
+            stop_profit_price=stop_profit_price
         )
         return self.send_order(original_req, orderid)
 
@@ -235,7 +244,9 @@ class OkexFutureUsdtGateway(BaseGateway):
               price: float = 0,  # 价格
               maker: bool = False,  # 限价单
               stop_loss: bool = False,  # 止损
+              stop_loss_price: float = 0,  # 止损价
               stop_profit: bool = False,  # 止盈
+              stop_profit_price: float = 0,  # 止盈价
               position_side: PositionSide = PositionSide.ONEWAY,
               ):
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -245,11 +256,13 @@ class OkexFutureUsdtGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.SHORT,
             offset=Offset.OPEN,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
-            exchange=self.exchange
+            exchange=self.exchange,
+            stop_loss_price=stop_loss_price,
+            stop_profit_price=stop_profit_price
         )
         return self.send_order(original_req, orderid)
 
@@ -261,9 +274,12 @@ class OkexFutureUsdtGateway(BaseGateway):
               price: float = 0,  # 价格
               maker: bool = False,  # 限价单
               stop_loss: bool = False,  # 止损
+              stop_loss_price: float = 0,  # 止损价
               stop_profit: bool = False,  # 止盈
+              stop_profit_price: float = 0,  # 止盈价
               position_side: PositionSide = PositionSide.ONEWAY,
               ):
+
         new_symbol = symbol_deal(symbol, self.exchange)
         self.symbolMap[new_symbol] = symbol
 
@@ -271,11 +287,13 @@ class OkexFutureUsdtGateway(BaseGateway):
             symbol=new_symbol,
             direction=Direction.LONG,
             offset=Offset.CLOSE,
-            type=get_order_type(maker, stop_loss, stop_profit),
+            type=get_order_type(maker, stop_loss, stop_profit, self.exchange),
             price=price,
             volume=volume,
             positionSide=position_side,
-            exchange=self.exchange
+            exchange=self.exchange,
+            stop_loss_price=stop_loss_price,
+            stop_profit_price=stop_profit_price
         )
         return self.send_order(original_req, orderid)
 
@@ -516,7 +534,15 @@ class OkexRestApi(RestClient):
 
         path: str = "/api/v5/trade/order"
 
-        if req.type == OrderType.STOP_MARKET:
+        if req.type == OrderType.STOP_LOSS_PROFIT:
+            params['slTriggerPx'] = str(req.stop_loss_price)  # 止损触发价
+            params['slOrdPx'] = '-1'  # 止损委托价,当为 -1 时。按市价止损
+            params['tpTriggerPx'] = str(req.stop_profit_price)  # 止盈触发价
+            params['tpOrdPx'] = '-1'  # 止盈委托价, 当为-1 时，按市价止盈
+            params['ordType'] = "oco"
+            path: str = "/api/v5/trade/order-algo"
+
+        elif req.type == OrderType.STOP_MARKET:
             params['slTriggerPx'] = str(req.price)  # 止损触发价
             params['slOrdPx'] = '-1'  # 止损委托价,当为 -1 时。按市价止损
             params['ordType'] = "conditional"
